#* 
#* ------------------------------------------------------------------
#* testdialog.tcl - Test dialog.
#* Created by Robert Heller on Mon Feb 20 13:06:21 2006
#* ------------------------------------------------------------------
#* Modification History: $Log: headerfile.text,v $
#* Modification History: Revision 1.1  2002/07/28 14:03:50  heller
#* Modification History: Add it copyright notice headers
#* Modification History:
#* ------------------------------------------------------------------
#* Contents:
#* ------------------------------------------------------------------
#*  
#* Copyright (c) 2006, Robert Heller
#* All rights reserved.
#* 
#* Redistribution and use in source and binary forms, with or without
#* modification, are permitted provided that the following conditions are
#* met:
#* 
#*     * Redistributions of source code must retain the above copyright
#*       notice, this list of conditions and the following disclaimer.
#*     * Redistributions in binary form must reproduce the above copyright
#*       notice, this list of conditions and the following disclaimer in the
#*       documentation and/or other materials provided with the distribution.
#*     * Neither the name of the Deepwoods Software nor the names of its
#*       contributors may be used to endorse or promote products derived from
#*       this software without specific prior written permission.
#* 
#* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
#* IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
#* TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
#* PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
#* OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
#* LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
#* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
#* THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
#* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
#* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#* 
#* 

package require BWidget
package require BWFileEntry
package require BWLabelComboBox

namespace eval OpenPrinterDialog {
  Widget::define OpenPrinterDialog testdialog Dialog FileEntry LabelComboBox
  Widget::bwinclude OpenPrinterDialog Dialog .pdialog \
	include {} \
	initialize {-class OpenPrinterDialog -bitmap questhead -default 0
		    -cancel 1 -modal local -transient yes -parent . 
		    -side bottom -title {Open Printer}}
  Widget::bwinclude OpenPrinterDialog FileEntry .pdialog.pfile \
	include {} \
	initialize {-label {Print file:} -labelwidth 16 -filedialog save 
		    -title {File to send printout to}}
  Widget::bwinclude OpenPrinterDialog LabelComboBox .pdialog.ptype \
	include {} \
	initialize [list -label {Type of printer:} -labelwidth 16 \
			 -values {Text LQ24 Postscript PDF}]
  ::bind BwOpenPrinterDialog <FocusIn> [list focus %W.pfile]
  ::bind BwOpenPrinterDialog <Destroy> [list OpenPrinterDialog::_destroy %W]
}

proc OpenPrinterDialog::create { path args } {
  array set maps [list OpenPrinterDialog {} :cmd {} .pdialog {} \
	.pdialog.pfile {} .pdialog.ptype {}]
  array set maps [Widget::parseArgs OpenPrinterDialog $args]

  eval [list frame $path] $maps(:cmd) -class OpenPrinterDialog \
	-relief flat -bd 0 -highlightthickness 0 -takefocus 0
  Widget::initFromODB OpenPrinterDialog $path $maps(OpenPrinterDialog)
  set dialog [eval [list Dialog::create $path.pdialog] $maps(.pdialog)]
  $dialog add -name ok -text OK -command [list OpenPrinterDialog::_openit $path]
  $dialog add -name cancel -text Cancel -command [list OpenPrinterDialog::_cancelit $path]
  $dialog add -name help -text Help -command [list BWHelp::HelpTopic OpenPrinterDialog]
  set uframe [$dialog getframe]
  set fileent [eval [list FileEntry::create $dialog.pfile] $maps(.pdialog.pfile)]
  pack $fileent -in $uframe -fill x
  set prtype [eval [list LabelComboBox::create $dialog.ptype] $maps(.pdialog.ptype)]
  pack $prtype -in $uframe -fill x
  bindtags $dialog [list $path BwOpenPrinterDialog $dialog]
  return [Widget::create OpenPrinterDialog $path]
}

proc OpenPrinterDialog::draw { path } {
#  BWidget::focus $path.pdialog.pfile 1
  return [eval [list Dialog::draw $path.pdialog]]
}

proc OpenPrinterDialog::withdraw { path } {
  return [eval [list Dialog::withdraw $path.pdialog]]
}

proc OpenPrinterDialog::enddialog { path result } {
  return [eval [list Dialog::enddialog $path.pdialog] [list $result]]
}

proc OpenPrinterDialog::_cancelit { path } {
  eval [list Dialog::withdraw $path.pdialog]
  return [eval [list Dialog::enddialog $path.pdialog] [list {}]]
}

proc OpenPrinterDialog::_openit { path } {
  set pfile [$path.pdialog.pfile cget -text]
  set printer [$path.pdialog.ptype cget -text]
  eval [list Dialog::withdraw $path.pdialog]
  return [eval [list Dialog::enddialog $path.pdialog] [list [list $pfile $printer]]]
}
  
proc OpenPrinterDialog::_destroy { path } {
  Widget::destroy $path
}

# ------------------------------------------------------------------------------
#  Command OpenPrinterDialog::configure
# ------------------------------------------------------------------------------
proc OpenPrinterDialog::configure { path args } {
    return [Widget::configure $path $args]
}


# ------------------------------------------------------------------------------
#  Command OpenPrinterDialog::cget
# ------------------------------------------------------------------------------
proc OpenPrinterDialog::cget { path option } {
    return [Widget::cget $path $option]
}

package provide OpenPrinterDialog 1.0
